summaryrefslogtreecommitdiffstats
path: root/src/hooks
diff options
context:
space:
mode:
authorDenys Vlasenko <dvlasenk@redhat.com>2010-10-13 16:22:13 +0200
committerDenys Vlasenko <dvlasenk@redhat.com>2010-10-13 16:22:13 +0200
commit00ce0e833e3d85d674037a077a30d5d8bf71585c (patch)
treed944d16eb23d2c7f9ec7d089f68a648ddfd03d8c /src/hooks
parent459e0825dd22438ad6962f59060e6f8dba07e26a (diff)
downloadabrt-00ce0e833e3d85d674037a077a30d5d8bf71585c.tar.gz
abrt-00ce0e833e3d85d674037a077a30d5d8bf71585c.tar.xz
abrt-00ce0e833e3d85d674037a077a30d5d8bf71585c.zip
don't catch crashes of any program which starts with "abrt", not only abrtd
Signed-off-by: Denys Vlasenko <dvlasenk@redhat.com>
Diffstat (limited to 'src/hooks')
-rw-r--r--src/hooks/abrt-hook-ccpp.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/hooks/abrt-hook-ccpp.cpp b/src/hooks/abrt-hook-ccpp.cpp
index a35bba11..656d5e29 100644
--- a/src/hooks/abrt-hook-ccpp.cpp
+++ b/src/hooks/abrt-hook-ccpp.cpp
@@ -388,14 +388,14 @@ int main(int argc, char** argv)
close(fd);
}
- if (strstr(executable, "/abrtd"))
+ if (strstr(executable, "/abrt"))
{
/* If abrtd crashes, we don't want to create a _directory_,
* since that can make new copy of abrtd to process it,
* and maybe crash again...
* Unlike dirs, mere files are ignored by abrtd.
*/
- snprintf(path, sizeof(path), "%s/abrtd-coredump", dddir);
+ snprintf(path, sizeof(path), "%s/abrt-coredump", dddir);
int abrt_core_fd = xopen3(path, O_WRONLY | O_CREAT | O_TRUNC, 0644);
off_t core_size = copyfd_eof(STDIN_FILENO, abrt_core_fd, COPYFD_SPARSE);
if (core_size < 0 || fsync(abrt_core_fd) != 0)
@@ -388,14 +388,14 @@ int main(int argc, char** argv)
{
- /* If abrtd crashes, we don't want to create a _directory_,
+ /* If abrtd/abrt-foo crashes, we don't want to create a _directory_,
* since that can make new copy of abrtd to process it,
* and maybe crash again...